@@ -14,18 +14,14 @@ import csv
 import os
 import StringIO
 import sys
+import unicodedata
 
 from collections import OrderedDict
 
-try:
-    from unicodenames import unicodenames
-    os.environ['UNAMES_INSTALLED'] = 'uname-installed'
-except ImportError:
-    pass
-
 
 from fontaine.const import SUPPORT_LEVEL_FULL, SUPPORT_LEVEL_UNSUPPORTED
 from fontaine.cmap import library
+from fontaine.font import Font
 from fontaine.structures.dict2xml import dict2xml, dict2txt
 
 
@@ -40,13 +36,12 @@ db = os.environ.get('UNAMES_DB') or os.path.join(os.path.dirname(__file__),
 
 def format(x):
     return u'U+%04x\x20\x20%s\x20\x20%s' % \
-        (x, unichr(x), unicodenames(db).name(x) or '')
+        (x, unichr(x), unicodedata.name(unichr(x), ''))
 
 
 def unicodevalues_asstring(values):
-    """ Return string with unicodenames if db defined """
-    if os.environ.get('UNAMES_INSTALLED') \
-            and not os.environ.get('DISABLE_UNAMES'):
+    """ Return string with unicodenames (unless that is disabled) """
+    if not os.environ.get('DISABLE_UNAMES'):
         return map(lambda x: '%s' % format(x).strip(), values)
     return map(lambda x: u'U+%04x %s' % (x, unichr(x)), values)
 
@@ -57,11 +52,57 @@ extract_firstline = lambda text: \
 
 class Director(object):
 
+    def __init__(self, generate_coverage=None, charmaps=[]):
+        self.generate_coverage = generate_coverage
+        self.charmaps = charmaps
+
+    def represent_coverage_png(self, font):
+        cmaps = filter(lambda x: hasattr(x, 'key'), library.charmaps)
+
+        if not os.path.exists('coverage_pngs'):
+            os.makedirs('coverage_pngs')
+
+        for cmap in cmaps:
+            if self.charmaps:
+                cn = getattr(cmap, 'common_name', False)
+                nn = getattr(cmap, 'native_name', False)
+                if cn and cn not in self._charmaps:
+                    continue
+                if nn and nn not in self._charmaps:
+                    continue
+
+            if cmap.key not in font._unicodeValues:
+                continue
+
+            filename = u'coverage_pngs/%s - %s' % (font.common_name,
+                                                   cmap.common_name)
+
+            txtFilename = filename + '.txt'
+            fp = open(txtFilename, 'w+')
+
+            glyphs = cmap.glyphs
+            if callable(glyphs):
+                glyphs = glyphs()
+            for i, char in enumerate(sorted(glyphs)):
+                flag = str(0)
+                if char in font._unicodeValues:
+                    flag = str(1)
+                fp.write(str(i + 1) + ' ' + flag + '\n')
+
+            fp.close()
+            hilbertScript = ('simpleHilbertCurve'
+                             ' --outFormat=png'
+                             ' --level=3'
+                             ' --out="%s" "%s"') % (filename, txtFilename)
+            os.system(hilbertScript)
+
     def construct_tree(self, fonts):
 
         tree = OrderedDict({'fonts': []})
 
-        for font in fonts:
+        for font_filename in fonts:
+            font = Font(font_filename, charmaps=self.charmaps)
+
             F = OrderedDict()
             desc = OrderedDict()
             desc['commonName'] = font.common_name
@@ -80,7 +121,8 @@ class Director(object):
             desc['designerUrl'] = font.designer_url
             desc['glyphCount'] = font.glyph_num
             desc['characterCount'] = font.character_count
-            for charmap, support_level, coverage, missing in font.get_orthographies():
+            for charmap, support_level, coverage, missing \
+                    in font.get_orthographies():
                 if support_level == SUPPORT_LEVEL_UNSUPPORTED:
                     continue
                 if 'orthographies' not in desc:
@@ -98,6 +140,9 @@ class Director(object):
 
                 desc['orthographies'].append(orth)
 
+            if self.generate_coverage:
+                self.represent_coverage_png(font)
+
             F['font'] = desc
             tree['fonts'].append(F)
 
